@@ -26,12 +26,9 @@ class MergeException(InferException):
         self.snd = snd
 
     def __str__(self):
-        get_label = lambda s: 'unnamed variable' if s.label is None else 'variable "{}"'.format(s.label)
+        get_label = lambda s: 'unnamed variable' if s.label is None else 'variable "{0}"'.format(s.label)
         def get_usage(s):
-            rv = s.__class__.__name__.lower()
-            if isinstance(s, Scalar):
-                rv += ' ({})'.format(', '.join(s.possible_types))
-            return rv
+            return s.__class__.__name__.lower()
         get_linenos = lambda s: ', '.join(map(str, s.linenos))
         return ('{fst_label} (used as {fst_usage} on lines {fst_linenos}) conflicts with '
                 '{snd_label} (used as {snd_usage} on lines: {snd_linenos})').format(
@@ -87,4 +84,4 @@ class InvalidExpression(InferException):
         self.message = message
 
     def __str__(self):
-        return 'line {}: {}'.format(self.ast.lineno, self.message)
\ No newline at end of file
+        return 'line {0}: {1}'.format(self.ast.lineno, self.message)
\ No newline at end of file
